@@ -3,13 +3,19 @@ import sympy as sp
 from lbmpy.innerloopsplit import create_lbm_split_groups
 from lbmpy.methods.momentbased.momentbasedmethod import MomentBasedLbMethod
 from lbmpy.methods.momentbased.centralmomentbasedmethod import CentralMomentBasedLbMethod
-from lbmpy.methods.centeredcumulant import CenteredCumulantBasedLbMethod
+from lbmpy.methods.cumulantbased import CumulantBasedLbMethod
+
+from lbmpy.methods.cumulantbased.cumulant_simplifications import (
+    insert_log_products, expand_post_collision_central_moments)
 from lbmpy.methods.momentbased.momentbasedsimplifications import (
     factor_density_after_factoring_relaxation_times, factor_relaxation_rates,
-    replace_common_quadratic_and_constant_term, replace_density_and_velocity, replace_second_order_velocity_products)
+    replace_common_quadratic_and_constant_term, replace_density_and_velocity, replace_second_order_velocity_products,
+    insert_half_force, insert_conserved_quantity_products)
 from pystencils.simp import (
     SimplificationStrategy, add_subexpressions_for_divisions, apply_to_all_assignments,
-    subexpression_substitution_in_main_assignments, insert_aliases, insert_constants)
+    subexpression_substitution_in_main_assignments, insert_aliases, insert_constants,
+    add_subexpressions_for_constants)
+# add_subexpressions_for_constants)
 
 
 def create_simplification_strategy(lb_method, split_inner_loop=False):
@@ -25,8 +31,8 @@ def create_simplification_strategy(lb_method, split_inner_loop=False):
                 return _mrt_population_space_simplification(split_inner_loop)
     elif isinstance(lb_method, CentralMomentBasedLbMethod):
         return _moment_space_simplification(split_inner_loop)
-    elif isinstance(lb_method, CenteredCumulantBasedLbMethod):
-        return _moment_space_simplification(split_inner_loop)
+    elif isinstance(lb_method, CumulantBasedLbMethod):
+        return _cumulant_space_simplification(split_inner_loop)
     else:
         return SimplificationStrategy()
 
@@ -56,6 +62,7 @@ def _srt_trt_population_space_simplification(split_inner_loop):
 def _mrt_population_space_simplification(split_inner_loop):
     s = SimplificationStrategy()
     s.add(subexpression_substitution_in_main_assignments)
+    s.add(add_subexpressions_for_divisions)
     if split_inner_loop:
         s.add(create_lbm_split_groups)
     s.add(lambda ac: ac.new_without_unused_subexpressions())
@@ -65,7 +72,28 @@ def _mrt_population_space_simplification(split_inner_loop):
 def _moment_space_simplification(split_inner_loop):
     s = SimplificationStrategy()
     s.add(insert_constants)
+    s.add(insert_half_force)
     s.add(insert_aliases)
+    s.add(add_subexpressions_for_divisions)
+    s.add(add_subexpressions_for_constants)
+    if split_inner_loop:
+        s.add(create_lbm_split_groups)
+    s.add(lambda ac: ac.new_without_unused_subexpressions())
+    return s
+
+
+def _cumulant_space_simplification(split_inner_loop):
+    s = SimplificationStrategy()
+    s.add(insert_constants)
+    s.add(insert_aliases)
+    s.add(insert_log_products)
+    s.add(insert_conserved_quantity_products)
+    s.add(insert_half_force)
+    s.add(expand_post_collision_central_moments)
+    s.add(insert_aliases)
+    s.add(insert_constants)
+    s.add(add_subexpressions_for_divisions)
+    s.add(add_subexpressions_for_constants)
     if split_inner_loop:
         s.add(create_lbm_split_groups)
     s.add(lambda ac: ac.new_without_unused_subexpressions())
