@@ -1,25 +1,16 @@
 import pytest
 import sympy as sp
-from dataclasses import replace
 
-from lbmpy.enums import Method, ForceModel, Stencil
-from lbmpy.moments import (
-    extract_monomials, get_default_moment_set_for_stencil, non_aliased_polynomial_raw_moments,
-    exponent_tuple_sort_key)
+from lbmpy.enums import Stencil
 from lbmpy.stencils import LBStencil
 
 from lbmpy.methods.creationfunctions import create_with_monomial_cumulants
 from lbmpy.maxwellian_equilibrium import get_weights
 
-from lbmpy.moment_transforms import (
-    PdfsToMomentsByMatrixTransform, PdfsToMomentsByChimeraTransform
-)
-
 
 @pytest.mark.parametrize('stencil', [Stencil.D2Q9, Stencil.D3Q19])
 def test_zero_centering_equilibrium_equivalence(stencil):
     stencil = LBStencil(stencil)
-    transform_class = PdfsToMomentsByChimeraTransform
     omega = sp.Symbol('omega')
     r_rates = (omega,) * stencil.Q
 
@@ -28,8 +19,8 @@ def test_zero_centering_equilibrium_equivalence(stencil):
     rho = sp.Symbol("rho")
     rho_background = sp.Integer(1)
     delta_rho = sp.Symbol("delta_rho")
-    
-    subs = { delta_rho : rho - rho_background }
+
+    subs = {delta_rho: rho - rho_background}
     eqs = []
 
     for zero_centered in [False, True]:
